summaryrefslogtreecommitdiffstats
path: root/lzip_index.h
diff options
context:
space:
mode:
Diffstat (limited to 'lzip_index.h')
-rw-r--r--lzip_index.h12
1 files changed, 10 insertions, 2 deletions
diff --git a/lzip_index.h b/lzip_index.h
index 822f537..de8fe19 100644
--- a/lzip_index.h
+++ b/lzip_index.h
@@ -55,7 +55,7 @@ class Lzip_index
const long long insize;
int retval_;
unsigned dictionary_size_; // largest dictionary size in the file
- bool bad_magic_; // bad magic in first header
+ bool good_magic_; // good magic in first header
bool check_header( const Lzip_header & header, const bool first );
void set_errno_error( const char * const msg );
@@ -70,7 +70,15 @@ public:
const std::string & error() const { return error_; }
int retval() const { return retval_; }
unsigned dictionary_size() const { return dictionary_size_; }
- bool bad_magic() const { return bad_magic_; }
+ bool good_magic() const { return good_magic_; }
+
+ bool multi_empty() const // multimember file with empty member(s)
+ {
+ if( member_vector.size() > 1 )
+ for( unsigned long i = 0; i < member_vector.size(); ++i )
+ if( member_vector[i].dblock.size() == 0 ) return true;
+ return false;
+ }
long long udata_size() const
{ if( member_vector.empty() ) return 0;